@@ -1,15 +1,12 @@
 
-
-
-dichromat<-function(colours,type=c("deutan","protan")){
-    
-    load(system.file("data","dichromat.rda",package="dichromat"))
-    require("modreg")
+dichromat<- function(colours,type=c("deutan","protan")){
+    data(dichromat, envir=environment())
+    require("stats")
     colours<-col2rgb(colours)
     colours<-t(colours)
     colnames(colours)<-c("r","g","b")
     type<-match.arg(type)
-
+    
     if(type=="deutan"){
         nred<-predict(redd,newdata=colours)
         ngreen<-predict(greend,newdata=colours)
@@ -19,10 +16,10 @@ dichromat<-function(colours,type=c("deutan","protan")){
         ngreen<-predict(greenp,newdata=colours)
         nblue<-predict(bluep,newdata=colours)
     }
-
+    
     nred<-pmax(0,pmin(1,nred/255))
     ngreen<-pmax(0,pmin(1,ngreen/255))
     nblue<-pmax(0,pmin(1,nblue/255))
-    rgb(nred,ngreen,nblue)
-
+        rgb(nred,ngreen,nblue)
+    
 }
